@@ -1,10 +1,14 @@
 context ("get contributors")
 
+test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
+    identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
+
+testthat::skip_if (!test_all)
+
 test_that ("get_contributors", {
 
-    vcr::use_cassette ("get_contribs", {
-
-        x <- get_contributors (org = "hypertidy", repo = "geodist")
+    x <- with_mock_dir ("getcontribs", {
+        get_contributors (org = "hypertidy", repo = "geodist")
     })
 
     expect_is (x, "data.frame")
